@@ -8,10 +8,13 @@
  */
 
 #include "extension/implementation/implementation.h"
-#include "extension/extension-forward.h"
 
 namespace Inkscape {
 namespace Extension {
+
+class Effect;
+class Extension;
+
 namespace Internal {
 
 /** \brief  Implementation class of the GIMP gradient plugin.  This mostly
@@ -21,8 +24,8 @@ class Grid : public Inkscape::Extension::Implementation::Implementation {
 
 public:
     bool load(Inkscape::Extension::Extension *module);
-    void effect(Inkscape::Extension::Effect *module, Inkscape::UI::View::View *document);
-    Gtk::Widget * prefs_effect(Inkscape::Extension::Effect *module, Inkscape::UI::View::View * view);
+    void effect(Inkscape::Extension::Effect *module, Inkscape::UI::View::View *document, Inkscape::Extension::Implementation::ImplementationDocumentCache * docCache);
+    Gtk::Widget * prefs_effect(Inkscape::Extension::Effect *module, Inkscape::UI::View::View * view, sigc::signal<void> * changeSignal, Inkscape::Extension::Implementation::ImplementationDocumentCache * docCache);
 
     static void init (void);
 };
